# virtru-tdf3-cpp · [![Build status](https://badge.buildkite.com/78ca7304b5b45bad9cf23fb20353c23e7c56b9d8b25ba0388f.svg)](https://buildkite.com/virtru/virtru-tdf3-cpp-pr)
Virtru client interface to generate TDF3 files.

Virtru TDF3 C++ SDK uses cmake as its build system to solve some cross-platform build system overhead. Since we use cmake the developer should be able to generate the project files(Xcode, Visual Studio, CLion,..) according to the preferences.

## Secrets for automated tests

The secrets (user/pass/appid/hmac/token/whatever) used for automated testing are being migrated to Vault secrets.  If you are doing an automated build, the VAULT_TOKEN environment variable will be set for you,
and the secrets will be retrieved using that.  If you are doing a local build, you will need to set VAULT_TOKEN manually.  You can do this in two ways:

1. Log in to https://vault.mgmt.virtru.com using your Okta account, and get the value using the account icon menu in the upper right corner of the page
2. From the command line, log in to Vault: 
`export VAULT_ADDR=https://vault.mgmt.virtru.com`
`vault login -method=okta username=your-username@virtru.com`
 

## Development on Mac OS

Tools required to build the virtru tdf3 library and run the sample

Homebrew

`ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"`

Cmake

`brew install cmake`

Python3

`brew install python3`

Go

`brew install go`

Conan

`brew install conan`

Virtru West VPN

`Some of the third-party  C++ packages are hosted on virtru nexus server,
 and downloading them as part of building the SDK requires
 a VPN. Open CAB request, and one of SRE engineers should able to get the VPN
 installed on the development machine.`

Once all these tools are installed run `$build-all.sh` to build the virtru tdf3 library and to
execute unit tests.

## Development on Linux

Ubuntu 18.04(as of 04/02/2019) is recommended for the development because `build-essential`
installs gcc 7.3 which supports C++ 17. TDF3 lib is build with Morden C++. Older version
of any linux operating system can be used but gcc version that supports C++ 17 is needed for
any development changes.

build-essential

`sudo apt install build-essential`

Cmake

`sudo apt install cmake`

Pip3

`sudo apt install python3-pip`

Conan

`pip3 install --user --upgrade conan `

Update the `PATH` to find the conan. `export PATH=$PATH:$(python3 -m site --user-base)/bin`

Valgrind - To detect any memory issues and leaks

`sudo apt-get install valgrind`

Virtru West VPN

`Some of the third-party  C++ packages are hosted on virtru nexus server,
 and downloading them as part of building the SDK requires
 a VPN. Open CAB request, and one of SRE engineers should able to get the VPN
 installed on the development machine.`
 
Once all these tools are installed run `$build-all.sh` to build the virtru tdf3 library and to execute unit tests.

To just build a Virtru TDF3 library and sample the docker image in `docker` can be used also.

## Development on Windows (64 bit)

Tools required to build the virtru tdf3 library and run the sample

Visual Studio 2017

`https://visualstudio.microsoft.com/downloads/`

Cmake

`https://github.com/Kitware/CMake/releases/download/v3.16.0-rc3/cmake-3.16.0-rc3-win64-x64.msi`

Python3

`https://www.python.org/ftp/python/3.7.5/python-3.7.5-amd64.exe`

Conan

`https://dl.bintray.com/conan/installers/conan-win-64_1_9_2.exe`

Virtru West VPN

`Some of the third-party  C++ packages are hosted on virtru nexus server,
 and downloading them as part of building the SDK requires
 a VPN. Open CAB request, and one of SRE engineers should able to get the VPN
 installed on the development machine.`

Once all these tools are installed run `build-all.bat` to build the virtru tdf3 library and to
execute unit tests.

By default, a release build is performed if BUILDKITE=1 (on a Buildkite agent), and a debug build is performed otherwise (on a developer local machine build)  
You may specify 'release' or 'debug' as an argument to build-all.bat to force the build type.

## Development on Windows (32 bit)

Same requirements as for W64, except that VSCMD_ARG_TGT_ARCH needs to be set to "x86" before build-env.bat is invoked.  This environment
variable is set by the vcvars32.bat file, so if you start an "x86 Native Tools Command Prompt for VS" window, it will be set properly.

No Python materials are produced by the 32 bit build.
